define(["exports", "../../../@polymer/polymer/polymer-element.js", "../../../@polymer/polymer/lib/utils/render-status.js", "../a11y-collapse.js"], function (_exports, _polymerElement, _renderStatus, _a11yCollapse) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.A11yCollapseGroup = void 0;

  function _templateObject_d2dfab30e53211e9a0cfefb808989d41() {
    var data = babelHelpers.taggedTemplateLiteral(["\n      <style>\n        :host {\n          display: block;\n          margin: var(--a11y-collapse-group-margin, 15px 0);\n          --a11y-collapse-margin: 15px;\n\n          @apply --a11y-collapse-group;\n        }\n        :host #heading {\n          font-weight: bold;\n          @apply --a11y-collapse-group-heading;\n        }\n        :host .wrapper {\n          border-radius: 0;\n          --a11y-collapse-margin: 0;\n          --a11y-collapse-border-between: none;\n        }\n      </style>\n      <div class=\"wrapper\"><slot></slot></div>\n    "]);

    _templateObject_d2dfab30e53211e9a0cfefb808989d41 = function _templateObject_d2dfab30e53211e9a0cfefb808989d41() {
      return data;
    };

    return data;
  }

  /**
   * `a11y-collapse-group`
   * A group of a11y-collapse elements
   * @microcopy - the mental model for this element```
  <a11y-collapse-group 
    global-options='{"prop": "value"}'     //Optional: An object that will automatica11y override and set properties for every a11y-collapse.
    radio>                                 //Optional: radio. If true, only one item in the group can be expanded at a time.
    <h2 slot="heading">Colors List</h2>    //Optional: Adds the slotted content above the group
    <a11y-collapse>...</a11y-collapse>     //An a11y-collapse item. See documentation for the a11y-collapse
  </a11y-collapse-group>
  
  CSS Mixins:
    --a11y-collapse-group                    //sets CSS for the a11y-collapse-group
    --a11y-collapse-group-heading            //sets CSS for the a11y-collapse-group heading
  ```
   *
   * @customElement
   * @polymer
   * @demo demo/accordion.html collapse groups
   */
  var A11yCollapseGroup =
  /*#__PURE__*/
  function (_PolymerElement) {
    babelHelpers.inherits(A11yCollapseGroup, _PolymerElement);
    babelHelpers.createClass(A11yCollapseGroup, null, [{
      key: "tag",
      get: function get() {
        return "a11y-collapse-group";
      }
    }, {
      key: "template",
      get: function get() {
        return (0, _polymerElement.html)(_templateObject_d2dfab30e53211e9a0cfefb808989d41());
      }
    }, {
      key: "properties",
      get: function get() {
        return {
          /**
           * an array of globalProperties to override every a11y-collapse item
           * For example, {"icon": "arrow-drop-down"} would set every item's icon to "arrow-drop-down"
           */
          globalOptions: {
            type: Object,
            value: {}
          },

          /**
           * is every a11y-collapse item radio button?
           */
          radio: {
            type: Boolean,
            value: false
          },

          /**
           * is radio button
           */
          __items: {
            type: Array,
            value: []
          }
        };
      }
    }]);

    function A11yCollapseGroup() {
      var _this;

      babelHelpers.classCallCheck(this, A11yCollapseGroup);
      _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(A11yCollapseGroup).call(this));

      _this.addEventListener("a11y-collapse-attached", function (e) {
        this._attachItem(e.detail);
      });

      _this.addEventListener("a11y-collapse-detached", function (e) {
        this._detachItem(e.detail);
      });

      _this.addEventListener("a11y-collapse-click", function (e) {
        this.radioToggle(e.detail);
      });

      return _this;
    }
    /**
     * Removes a detached item from the _items array.
     */


    babelHelpers.createClass(A11yCollapseGroup, [{
      key: "_attachItem",
      value: function _attachItem(item) {
        for (var key in this.globalOptions) {
          if (this.globalOptions.hasOwnProperty(key)) {
            item._overrideProp(key, this.globalOptions[key]);
          }
        }

        this.push("__items", item);
        this.notifyPath("__items");
      }
      /**
       * Removes a detached item from the _items array.
       */

    }, {
      key: "_detachItem",
      value: function _detachItem(item) {
        if (this.__items && item) {
          for (var i = 0; i < this.__items.length; i++) {
            if (this.__items[i] === item) this.splice("__items", i, 1);
          }
        }
      }
      /**
       * Toggles off all previous choices.
       */

    }, {
      key: "radioToggle",
      value: function radioToggle(item) {
        if (this.radio && item.expanded) {
          for (var i = 0; i < this.__items.length; i++) {
            if (this.__items[i] !== item) this.__items[i].toggle(false);
          }
        }
      }
    }, {
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        this.removeEventListener("a11y-collapse-click", function (e) {
          this.radioToggle(e.detail);
        });
        this.removeEventListener("a11y-collapse-attached", function (e) {
          this.push("__items", e.detail);
        });
        this.removeEventListener("a11y-collapse-detached", function (e) {
          this._detachItem(e.detail);
        });
        babelHelpers.get(babelHelpers.getPrototypeOf(A11yCollapseGroup.prototype), "disconnectedCallback", this).call(this);
      }
    }]);
    return A11yCollapseGroup;
  }(_polymerElement.PolymerElement);

  _exports.A11yCollapseGroup = A11yCollapseGroup;
  window.customElements.define(A11yCollapseGroup.tag, A11yCollapseGroup);
});