define(["exports", "require", "../hax-body/lib/hax-store.js"], function (_exports, _require, _haxStore) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.HAX = void 0;
  _require = babelHelpers.interopRequireWildcard(_require);

  /**
   * Copyright 2018 The Pennsylvania State University
   * @license Apache-2.0, see License.md for full text.
   */

  /**
   * `h-a-x`
   * `Single tag to transform authoring`
   *
   * @microcopy - language worth noting:
   *  - HAX - Headless Authoring eXperience
   *  - Body - the editable area that can be worked on and gets saved as a string / blob
   *
   * @customElement
   * @demo demo/index.html
   */
  var HAX =
  /*#__PURE__*/
  function (_HTMLElement) {
    babelHelpers.inherits(HAX, _HTMLElement);
    babelHelpers.createClass(HAX, [{
      key: "html",
      // render function
      get: function get() {
        return "\n<style>:host {\n  display: block;\n  font-size: var(--haxcms-base-styles-body-font-size, 16px);\n  font-family: var(--haxcms-base-styles-body-font-family, 'Noto Serif', serif);\n  line-height: var(--haxcms-base-styles-body-line-height, 1.8);\n  letter-spacing: var(--haxcms-base-styles-body-letter-spacing, .5px);\n}\n\n:host([hidden]) {\n  display: none;\n}\n\nhax-body {\n  font-size: var(--haxcms-base-styles-body-font-size, 16px);\n  font-family: var(--haxcms-base-styles-body-font-family, 'Noto Serif', serif);\n  line-height: var(--haxcms-base-styles-body-line-height, 1.8);\n  letter-spacing: var(--haxcms-base-styles-body-letter-spacing, .5px);\n}\n\nh1 {\n  font-size: var(--hax-base-styles-h1-font-size, 2.5em);\n  line-height: var(--hax-base-styles-h1-line-height, 2.5em);\n}\nh2 {\n  font-size: var(--hax-base-styles-h2-font-size, 2em);\n}\nh3 {\n  font-size: var(--hax-base-styles-h3-font-size, 1.75em);\n}\nh4 {\n  font-size: var(--hax-base-styles-h4-font-size, 1.5em);\n}\nh5 {\n  font-size: var(--hax-base-styles-h5-font-size, 1.25em);  \n}\nh6 {\n  font-size: var(--hax-base-styles-h6-font-size, 1.25em);\n}\np {\n  min-height: var(--hax-base-styles-p-min-height, 43px);\n  font-size: var(--hax-base-styles-p-font-size, 24px);\n  line-height: var(--hax-base-styles-p-line-height, 1.8);\n  letter-spacing: var(--hax-base-styles-p-letter-spacing, .5px);\n}\na,\na:-webkit-any-link {\n  color: var(--hax-base-styles-a-color, #2196f3);\n  font-size: var(--hax-base-styles-a-font-size, 24px);\n  font-weight: var(--hax-base-styles-a-font-weight, normal);\n}\na:visited {\n  color: var(--hax-base-styles-a-color-visited, #2196f3);\n}\na:active,\na:focus,\na:hover {\n  color: var(--hax-base-styles-a-color-active, #2196f3);\n  font-weight: var(--hax-base-styles-a-font-weight-active, normal);\n}\nol,\nul\nol li,\nul li {\n  padding-bottom: var(--hax-base-styles-list-padding-bottom, 1.5em);\n  line-height: var(--hax-base-styles-list-line-height, 40px);\n  font-size: var(--hax-base-styles-list-font-size, 24px);\n  max-width: var(--hax-base-styles-list-max-width, 28em);\n}\nol li:last-child,\nul li:last-child {\n  padding-bottom: var(--hax-base-styles-list-last-child-padding-bottom, 1em);\n}\nul,\nol {\n  padding-left: var(--hax-base-styles-list-padding-left, 20px);\n  padding-left: var(--hax-base-styles-list-margin-left, 20px);\n}</style>\n<hax-body>\n    <slot></slot>\n</hax-body>";
      } // properties available to the custom element for data binding

    }], [{
      key: "properties",
      get: function get() {
        var props = {
          appStore: {
            name: "appStore",
            type: String,
            value: ""
          }
        };

        if (babelHelpers.get(babelHelpers.getPrototypeOf(HAX), "properties", this)) {
          props = Object.assign(props, babelHelpers.get(babelHelpers.getPrototypeOf(HAX), "properties", this));
        }

        return props;
      }
      /**
       * Store the tag name to make it easier to obtain directly.
       * @notice function name must be here for tooling to operate correctly
       */

    }, {
      key: "tag",
      get: function get() {
        return "h-a-x";
      }
      /**
       * life cycle
       */

    }]);

    function HAX() {
      var _this;

      var delayRender = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      babelHelpers.classCallCheck(this, HAX);
      _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(HAX).call(this)); // set tag for later use

      _this.tag = HAX.tag; // map our imported properties json to real props on the element
      // @notice static getter of properties is built via tooling
      // to edit modify src/HAX-properties.json

      var obj = HAX.properties;

      for (var p in obj) {
        if (obj.hasOwnProperty(p)) {
          if (_this.hasAttribute(p)) {
            _this[p] = _this.getAttribute(p);
          } else {
            _this.setAttribute(p, obj[p].value);

            _this[p] = obj[p].value;
          }
        }
      }

      _this.template = document.createElement("template");

      _this.attachShadow({
        mode: "open"
      }); // if we shouldn't delay rendering


      if (!delayRender) {
        _this.render();
      }

      window.addEventListener("hax-store-ready", _this.storeReady.bind(babelHelpers.assertThisInitialized(_this)));
      window.addEventListener("hax-store-app-store-loaded", _this.appStoreReady.bind(babelHelpers.assertThisInitialized(_this))); // dynamically import definitions for all needed tags

      new Promise(function (res, rej) {
        return _require.default(["./lib/h-a-x-dependencies.js"], res, rej);
      });
      return _this;
    }
    /**
     * life cycle, element is afixed to the DOM
     */


    babelHelpers.createClass(HAX, [{
      key: "connectedCallback",
      value: function connectedCallback() {
        if (babelHelpers.get(babelHelpers.getPrototypeOf(HAX.prototype), "connectedCallback", this)) {
          babelHelpers.get(babelHelpers.getPrototypeOf(HAX.prototype), "connectedCallback", this).call(this);
        } // this ensures it's only applied once


        if (!this.__HAXApplied && !window.__HAXApplied) {
          window.__HAXApplied = this.__HAXApplied = this.applyHAX();
        }
      }
      /**
       * Store is ready, now we can pass along the app store definition
       * which HAX will react to an load the data it finds.
       */

    }, {
      key: "storeReady",
      value: function storeReady(e) {
        if (e.detail) {
          window.HaxStore.instance.appStore = JSON.parse(this.getAttribute("app-store"));
        }
      }
      /**
       * Appstore has been loaded, NOW we can safely do an import
       */

    }, {
      key: "appStoreReady",
      value: function appStoreReady(e) {
        if (e.detail) {
          // import into the active body if there's content
          // obtain the nodes that have been assigned to the slot of our element
          if (this.shadowRoot.querySelector("slot")) {
            var nodes = this.shadowRoot.querySelector("slot").assignedNodes();
            var body = ""; // loop the nodes and if it has an outerHTML attribute, append as string

            for (var i in nodes) {
              if (babelHelpers.typeof(nodes[i].outerHTML) !== (typeof undefined === "undefined" ? "undefined" : babelHelpers.typeof(undefined))) {
                body += nodes[i].outerHTML;
              }
            }

            window.HaxStore.instance.activeHaxBody.importContent(body);
          }
        }
      }
    }, {
      key: "render",
      value: function render() {
        if (!this.__rendered) {
          this.__rendered = true;
          this.shadowRoot.innerHTML = null;
          this.template.innerHTML = this.html;
          this.shadowRoot.appendChild(this.template.content.cloneNode(true));
        }
      }
      /**
       * Apply tags to the screen to establish HAX
       */

    }, {
      key: "applyHAX",
      value: function applyHAX() {
        // store needs to come before anyone else, use it's availability request mechanism
        window.HaxStore.requestAvailability(); // now everyone else

        var panel = document.createElement("hax-panel");
        panel.hidePanelOps = this.hidePanelOps;
        document.body.appendChild(panel);
        document.body.appendChild(document.createElement("hax-manager"));
        document.body.appendChild(document.createElement("hax-app-picker"));
        document.body.appendChild(document.createElement("hax-stax-picker"));
        document.body.appendChild(document.createElement("hax-blox-picker"));
        document.body.appendChild(document.createElement("hax-preferences-dialog"));
        document.body.appendChild(document.createElement("hax-export-dialog"));
        document.body.appendChild(document.createElement("hax-autoloader"));
        return true;
      }
    }, {
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        window.removeEventListener("hax-store-ready", this.storeReady.bind(this));
        window.removeEventListener("hax-store-ready", this.appStoreReady.bind(this));

        if (babelHelpers.get(babelHelpers.getPrototypeOf(HAX.prototype), "disconnectedCallback", this)) {
          babelHelpers.get(babelHelpers.getPrototypeOf(HAX.prototype), "disconnectedCallback", this).call(this);
        }
      }
    }, {
      key: "attributeChangedCallback",
      value: function attributeChangedCallback(attr, oldValue, newValue) {}
    }, {
      key: "hidePanelOps",
      get: function get() {
        return this.getAttribute("hide-panel-ops");
      },
      set: function set(newValue) {
        if (newValue) {
          this.setAttribute("hide-panel-ops", "hide-panel-ops");
        }
      }
    }, {
      key: "appStore",
      get: function get() {
        return this.getAttribute("app-store");
      },
      set: function set(newValue) {
        if (this.__rendered) {
          this.setAttribute("app-store", newValue); // bind to the hax store global on change

          window.HaxStore.instance.appStore = JSON.parse(this.getAttribute("app-store"));
        }
      }
    }], [{
      key: "observedAttributes",
      get: function get() {
        return ["app-store", "hide-panel-ops"];
      }
    }]);
    return HAX;
  }(babelHelpers.wrapNativeSuper(HTMLElement));

  _exports.HAX = HAX;
  window.customElements.define("h-a-x", HAX);
});