define(["exports", "require", "../../@polymer/polymer/polymer-element.js", "../../@polymer/polymer/lib/utils/render-status.js", "../simple-colors/simple-colors.js"], function (_exports, _require, _polymerElement, _renderStatus, _simpleColors) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.PlaceHolder = void 0;
  _require = babelHelpers.interopRequireWildcard(_require);

  function _templateObject_bb62f160e53211e9a0cfefb808989d41() {
    var data = babelHelpers.taggedTemplateLiteral(["\n      <style include=\"simple-colors-shared-styles\">\n        :host {\n          display: block;\n          border: none;\n          transition: 0.2s all linear;\n        }\n        :host([drag-over]) {\n          border: 4px dashed #2196f3;\n        }\n        .placeholder-inner {\n          text-align: center;\n          padding: 16px;\n          color: var(--simple-colors-default-theme-grey-11, #222222);\n          background-color: var(--simple-colors-default-theme-grey-2, #eeeeee);\n        }\n        iron-icon.placeholder-icon {\n          margin: 0 auto;\n          width: 50%;\n          height: 50%;\n          display: block;\n        }\n        .placeholder-text {\n          line-height: 24px;\n          font-size: 24px;\n          font-style: italic;\n        }\n      </style>\n      <div class=\"placeholder-inner\">\n        <iron-icon icon=\"[[iconFromType]]\" class=\"placeholder-icon\"></iron-icon>\n        <span class=\"placeholder-text\">[[calcText]]</span>\n      </div>\n    "]);

    _templateObject_bb62f160e53211e9a0cfefb808989d41 = function _templateObject_bb62f160e53211e9a0cfefb808989d41() {
      return data;
    };

    return data;
  }

  /**
   * `place-holder`
   * Placeholder for a piece of media in the future
   *
   * @demo demo/index.html
   *
   * @microcopy - the mental model for this element
   * - placeholder is a grey block on the page which can respond to drag and drop
   */
  var PlaceHolder =
  /*#__PURE__*/
  function (_PolymerElement) {
    babelHelpers.inherits(PlaceHolder, _PolymerElement);

    function PlaceHolder() {
      babelHelpers.classCallCheck(this, PlaceHolder);
      return babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(PlaceHolder).apply(this, arguments));
    }

    babelHelpers.createClass(PlaceHolder, [{
      key: "fireReplaceEvent",

      /**
       * Fire an event for things to react to above us
       */
      value: function fireReplaceEvent(e) {
        this.dispatchEvent(new CustomEvent("place-holder-replace", {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: this.type
        }));
      }
      /**
       * Get the calculated text based on text being empty and type being set.
       */

    }, {
      key: "_getCalcText",
      value: function _getCalcText(text, type, dragOver) {
        if (dragOver) {
          return "Upload file";
        } else if (text === "") {
          return "Place holder for " + type + ".";
        } else {
          return text;
        }
      }
      /**
       * Generate an icon based on the media type selected
       * for the place holder.
       */

    }, {
      key: "_getIconFromType",
      value: function _getIconFromType(type, dragOver) {
        if (!dragOver) {
          switch (type) {
            case "document":
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/editor-icons.js"], res, rej);
              });
              return "editor:insert-drive-file";
              break;

            case "audio":
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/av-icons.js"], res, rej);
              });
              return "av:music-video";
              break;

            case "video":
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/notification-icons.js"], res, rej);
              });
              return "notification:ondemand-video";
              break;

            case "image":
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/image-icons.js"], res, rej);
              });
              return "image:crop-original";
              break;

            case "math":
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/editor-icons.js"], res, rej);
              });
              return "editor:functions";
              break;

            case "text":
            default:
              new Promise(function (res, rej) {
                return _require.default(["../../@polymer/iron-icons/editor-icons.js"], res, rej);
              });
              return "editor:format-align-left";
              break;
          }
        } else {
          new Promise(function (res, rej) {
            return _require.default(["../../@polymer/iron-icons/iron-icons.js"], res, rej);
          }); // we are dragging, ignore icon

          return "icons:file-upload";
        }
      }
      /**
       * Attached to the DOM, now fire.
       */

    }, {
      key: "connectedCallback",
      value: function connectedCallback() {
        babelHelpers.get(babelHelpers.getPrototypeOf(PlaceHolder.prototype), "connectedCallback", this).call(this);
        (0, _renderStatus.afterNextRender)(this, function () {
          this.addEventListener("dragover", function (e) {
            this.dragOver = true;
            e.preventDefault();
            e.stopPropagation();
            this.classList.add("dragover");
          });
          this.addEventListener("dragleave", function (e) {
            this.dragOver = false;
            e.preventDefault();
            e.stopPropagation();
            this.classList.remove("dragover");
          }); // self bind a drop event enough though something else
          // will need to step in and do something with this.
          // We are just making sure that this doesn't redirect the browser.

          this.addEventListener("drop", function (e) {
            this.dragOver = false;
            e.preventDefault();
            e.stopPropagation();
            this.classList.remove("dragover"); // this helps ensure that what gets drag and dropped is a file
            // this prevents issues with selecting and dragging text (which triggers drag/drop)
            // as well as compatibility with things that are legit in a draggable state

            try {
              if (e.dataTransfer.items[0].kind === "file") {
                e.placeHolderElement = this; // fire this specialized event up so things like HAX can intercept

                this.dispatchEvent(new CustomEvent("place-holder-file-drop", {
                  bubbles: true,
                  cancelable: true,
                  composed: true,
                  detail: e
                }));
              }
            } catch (e) {}
          });
          this.addEventListener("dblclick", this.fireReplaceEvent.bind(this));
        });
      }
    }, {
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        this.removeEventListener("dragover", function (e) {
          this.dragOver = true;
          e.preventDefault();
          e.stopPropagation();
          this.classList.add("dragover");
        });
        this.removeEventListener("dragleave", function (e) {
          this.dragOver = false;
          e.preventDefault();
          e.stopPropagation();
          this.classList.remove("dragover");
        }); // self bind a drop event enough though something else
        // will need to step in and do something with this.
        // We are just making sure that this doesn't redirect the browser.

        this.removeEventListener("drop", function (e) {
          this.dragOver = false;
          e.preventDefault();
          e.stopPropagation();
          this.classList.remove("dragover"); // this helps ensure that what gets drag and dropped is a file
          // this prevents issues with selecting and dragging text (which triggers drag/drop)
          // as well as compatibility with things that are legit in a draggable state

          try {
            if (e.dataTransfer.items[0].kind === "file") {
              e.placeHolderElement = this; // fire this specialized event up so things like HAX can intercept

              this.dispatchEvent(new CustomEvent("place-holder-file-drop", {
                bubbles: true,
                cancelable: true,
                composed: true,
                detail: e
              }));
            }
          } catch (e) {}
        });
        this.removeEventListener("dblclick", this.fireReplaceEvent.bind(this));
        babelHelpers.get(babelHelpers.getPrototypeOf(PlaceHolder.prototype), "disconnectedCallback", this).call(this);
      }
    }], [{
      key: "template",
      get: function get() {
        return (0, _polymerElement.html)(_templateObject_bb62f160e53211e9a0cfefb808989d41());
      }
    }, {
      key: "tag",
      get: function get() {
        return "place-holder";
      }
    }, {
      key: "properties",
      get: function get() {
        return {
          /**
           * calculate an icon based on the type that was used
           */
          iconFromType: {
            type: String,
            computed: "_getIconFromType(type, dragOver)"
          },

          /**
           * Text place holder for describing this place holder element.
           */
          text: {
            type: String,
            value: ""
          },

          /**
           * Calculate text based on the type in the event we have no default.
           */
          calcText: {
            type: String,
            computed: "_getCalcText(text, type, dragOver)"
          },

          /**
           * A media type to visualize and also bubble events off of.
           */
          type: {
            type: String,
            value: "text"
          },

          /**
           * Bind dragging state to a variable so we can apply CSS.
           */
          dragOver: {
            type: Boolean,
            value: false,
            reflectToAttribute: true
          }
        };
      }
    }, {
      key: "haxProperties",
      get: function get() {
        return {
          canScale: true,
          canPosition: true,
          canEditSource: false,
          gizmo: {
            title: "Placeholder",
            description: "A place holder that can be converted into the media type that's been selected",
            icon: "image:transform",
            color: "grey",
            groups: ["Placeholder"],
            handles: [],
            meta: {
              author: "LRNWebComponents"
            }
          },
          settings: {
            quick: [],
            configure: [{
              property: "type",
              title: "Type",
              description: "Type of gizmo that this accepts for replacement.",
              inputMethod: "select",
              options: {
                text: "Text / content",
                document: "Document / file",
                audio: "Audio",
                video: "Video",
                image: "Image",
                math: "Math"
              }
            }, {
              property: "text",
              title: "Text",
              description: "Identify the place holder desired in greater detail",
              inputMethod: "textfield",
              required: false
            }],
            advanced: []
          },
          saveOptions: {
            unsetAttributes: ["icon-from-type", "calc-text"],
            wipeSlot: true
          }
        };
      }
    }]);
    return PlaceHolder;
  }(_polymerElement.PolymerElement);

  _exports.PlaceHolder = PlaceHolder;
  window.customElements.define(PlaceHolder.tag, PlaceHolder);
});