define(["exports", "../../../@polymer/polymer/polymer-element.js", "../simple-modal.js"], function (_exports, _polymerElement, _simpleModal) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.SimpleModalTemplate = void 0;

  function _templateObject_f4ed2ae0e53211e9a0cfefb808989d41() {
    var data = babelHelpers.taggedTemplateLiteral(["\n      <style>\n        :host {\n          display: none;\n          --simple-modal-width: auto;\n          --simple-modal-height: auto;\n          --simple-modal-min-width: unset;\n          --simple-modal-min-height: unset;\n          --simple-modal-max-width: unset;\n          --simple-modal-max-height: unset;\n          --simple-modal-titlebar-color: #444;\n          --simple-modal-titlebar-background: #ddd;\n          --simple-modal-header-color: #222;\n          --simple-modal-header-background: #ccc;\n          --simple-modal-content-container-color: #222;\n          --simple-modal-content-container-background: #fff;\n          --simple-modal-buttons-color: blue;\n          --simple-modal-buttons-background: #fff;\n          --simple-modal-button-color: var(--simple-modal-buttons-color);\n          --simple-modal-button-background: var(\n            --simple-modal-buttons-background-color\n          );\n        }\n      </style>\n      <slot name=\"header\"></slot> <slot name=\"content\"></slot>\n      <slot name=\"buttons\"></slot>\n    "]);

    _templateObject_f4ed2ae0e53211e9a0cfefb808989d41 = function _templateObject_f4ed2ae0e53211e9a0cfefb808989d41() {
      return data;
    };

    return data;
  }

  /**
   * `simple-modal-template`
   * `A simple modal that ensures accessibility and stack order context appropriately`
   *
   * @microcopy - language worth noting:
   *  -
   *
   * @customElement
   * @polymer
   * @demo demo/template.html
   */
  var SimpleModalTemplate =
  /*#__PURE__*/
  function (_PolymerElement) {
    babelHelpers.inherits(SimpleModalTemplate, _PolymerElement);

    function SimpleModalTemplate() {
      babelHelpers.classCallCheck(this, SimpleModalTemplate);
      return babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(SimpleModalTemplate).apply(this, arguments));
    }

    babelHelpers.createClass(SimpleModalTemplate, [{
      key: "associateEvents",

      /**
       * sets event listeners for a specified target
       *
       * @param {object} the object that will have the event listener
       * @param {string} the event name
       * @param {boolean} whether the event bubbles (default is true)
       * @param {boolean} whether the event can be canceled (default is true)
       * @returns {object} the modal object
       */
      value: function associateEvents(target) {
        var _this = this;

        var evt = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "click";
        var bubbles = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
        var cancelable = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
        target.addEventListener(evt, function (e) {
          _this.openModal(target, bubbles, cancelable);
        });
        return this.modal;
      }
      /**
       * gets the simple-modal
       *
       * @returns {object} the modal object
       */

    }, {
      key: "_getModal",
      value: function _getModal() {
        return window.SimpleModal.requestAvailability();
      }
      /**
       * dispatches event to populate and open the simple modal based template values
       *
       * @param {object} the object that will have the event listener
       * @param {boolean} whether the event bubbles (default is true)
       * @param {boolean} whether the event can be canceled (default is true)
       */

    }, {
      key: "openModal",
      value: function openModal(target) {
        var bubbles = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
        var cancelable = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
        var tplStyles = getComputedStyle(this),
            styles = {};
        ["--simple-modal-width", "--simple-modal-height", "--simple-modal-min-width", "--simple-modal-min-height", "--simple-modal-max-width", "--simple-modal-max-height", "--simple-modal-titlebar-color", "--simple-modal-titlebar-background", "--simple-modal-header-color", "--simple-modal-header-background", "--simple-modal-content-container-color", "--simple-modal-content-container-background", "--simple-modal-buttons-color", "--simple-modal-buttons-background", "--simple-modal-button-color", "--simple-modal-button-background"].forEach(function (prop) {
          styles[prop] = tplStyles.getPropertyValue(prop);
        });
        var evt = new CustomEvent("simple-modal-show", {
          bubbles: bubbles,
          cancelable: cancelable,
          composed: true,
          detail: {
            id: this.getAttribute("modal-id"),
            elements: {
              header: this._getSlot("header"),
              content: this._getSlot("content"),
              buttons: this._getSlot("buttons")
            },
            invokedBy: target,
            modalClass: this.getAttribute("class"),
            styles: styles,
            clone: false,
            title: this.title !== null ? this.title : false
          }
        });
        window.dispatchEvent(evt);
      }
      /**
       * clones content in a named slot
       *
       * @param {string} the name of the slot
       * @returns {object} a clone of the slotted content (or false if there is no slotted content)
       */

    }, {
      key: "_getSlot",
      value: function _getSlot(slotName) {
        var slot = this.querySelector('[slot="' + slotName + '"]');
        return slot !== null ? slot.cloneNode(true) : false;
      }
    }], [{
      key: "tag",

      /* REQUIRED FOR TOOLING DO NOT TOUCH */

      /**
       * Store the tag name to make it easier to obtain directly.
       * @notice function name must be here for tooling to operate correctly
       */
      get: function get() {
        return "simple-modal-template";
      } //render function

    }, {
      key: "properties",
      get: function get() {
        return {
          /**
           * the desired id for the modal
           */
          modalId: {
            type: Object,
            value: null
          },

          /**
           * the simple-modal
           */
          modal: {
            type: Object,
            computed: "_getModal()"
          },

          /**
           * the modal title
           */
          title: {
            type: String,
            value: ""
          }
        };
      } //render function

    }, {
      key: "template",
      get: function get() {
        return (0, _polymerElement.html)(_templateObject_f4ed2ae0e53211e9a0cfefb808989d41());
      }
    }]);
    return SimpleModalTemplate;
  }(_polymerElement.PolymerElement);

  _exports.SimpleModalTemplate = SimpleModalTemplate;
  window.customElements.define(SimpleModalTemplate.tag, SimpleModalTemplate);
});